@@ -272,11 +272,13 @@ public:
     rendition=c.rendition;
     fgColor=c.foregroundColor;
     bgColor=c.backgroundColor;
+    isRealCharacter = c.isRealCharacter;
   }
 
   CharacterColor fgColor, bgColor;
   quint16 startPos;
   quint8 rendition;
+  bool isRealCharacter;
 };
 
 class CompactHistoryBlock
