@@ -27,6 +27,7 @@
 // Standard
 #include <stdlib.h>
 #include <signal.h>
+#include <unistd.h>
 
 // Qt
 #include <QtGui/QApplication>
@@ -363,7 +364,7 @@ QString Session::checkProgram(const QString& program) const
 {
     // Upon a KPty error, there is no description on what that error was...
     // Check to see if the given program is executable.
-    QString exec = QFile::encodeName(program);
+    QString exec = program;
 
     if (exec.isEmpty())
         return QString();
@@ -742,6 +743,7 @@ void Session::refresh()
 
     const QSize existingSize = _shellProcess->windowSize();
     _shellProcess->setWindowSize(existingSize.height(),existingSize.width()+1);
+    usleep(500); // introduce small delay to avoid changing size too quickly
     _shellProcess->setWindowSize(existingSize.height(),existingSize.width());
 }
 
