@@ -124,7 +124,7 @@ void PlainTextDecoder::decodeLine(const Character* const characters, int count,
             {
                 const QString s = QString::fromUtf16(chars, extendedCharLength);
                 plainText.append(s);
-                i += string_width(s);
+                i += qMax(1, string_width(s));
             }
         }
         else
